@@ -1,3 +1,4 @@
+# $Id: en_us.pm 507 2005-06-08 03:17:04Z claco $
 package Handel::L10N::en_us;
 use strict;
 use warnings;
@@ -17,15 +18,11 @@ __END__
 
 =head1 NAME
 
-Handel::L10N::en_us - US English Language Pack for Handel
-
-=head1 VERSION
-
-    $Id: en_us.pm 33 2004-12-31 02:12:40Z claco $
+Handel::L10N::en_us - Handel Language Pack: US English
 
 =head1 AUTHOR
 
     Christopher H. Laco
     CPAN ID: CLACO
-    cpan@chrislaco.com
+    claco@chrislaco.com
     http://today.icantfocus.com/blog/
\ No newline at end of file
